@@ -137,6 +137,9 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
     def get_site_web_apps_sessions_path(self):
         return self._getlegacy("SITE_WEB_APPS_SESSIONS_PATH", os.path.join(self.get_site_web_apps_top_sessions_path(), "sessions"))
 
+    def get_wf_logs_path(self):
+        return os.path.join(self.get_site_web_apps_top_sessions_path(), "wf-logs")
+
     def get_site_annot_tools_path(self):
         return self._getlegacy("SITE_ANNOT_TOOLS_PATH", os.path.join(self.get_site_packages_path(), "annotation"))
 
@@ -195,7 +198,7 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
     def get_taxdump_path(self):
         reference_path = self._getreferencedir()
         site_pdbx_dict_path = os.path.join(reference_path, "taxdump")
-        return self._getlegacy("SITE_TAXDUMP_PATH", site_pdbx_dict_path)
+        return self._getlegacy("SITE_REFDATA_TAXONOMY_PATH", site_pdbx_dict_path)
 
     def get_idcode_dir(self):
         reference_path = self._getreferencedir()
@@ -339,15 +342,24 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
     def get_volume_server_query_path(self):
         return os.path.join(self.get_volume_server_packages_path(), "query.js")
 
+    def get_db_loader_path(self):
+        return os.path.join(self.get_site_packages_path(), "dbloader", "bin", "db-loader")
+
     def get_resources_da_internal_path(self):
         return os.path.join(self._getresourcedir(), "da_internal")
 
+    def get_resources_da_internal_all_path(self):
+        return os.path.join(self._getresourcedir(), "da_internal_all")
+
     def get_site_da_internal_schema_path(self):
         return self._getlegacy("SITE_DA_INTERNAL_SCHEMA_PATH", os.path.join(self.get_resources_da_internal_path(), "status_rcsb_schema_da.cif"))
 
     def get_site_da_internal_status_schema_path(self):
         return self._getlegacy("SITE_DA_INTERNAL_STATUS_SCHEMA_PATH", os.path.join(self.get_resources_da_internal_path(), "database_status_history_schema.cif"))
 
+    def get_site_da_internal_public_schema_path(self):
+        return self._getlegacy("SITE_DA_INTERNAL_PUBLIC_SCHEMA_PATH", os.path.join(self.get_resources_da_internal_all_path(), "schema_map_pdbx_v5.cif"))
+
     def get_resources_wfe_path(self):
         return os.path.join(self._getresourcedir(), "wfe")
 
