@@ -259,6 +259,14 @@ class ConfigInfoData(object):
         "em-mask-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-mask-volume"),
         "em-additional-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-additional-volume"),
         "em-half-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-half-volume"),
+        "em-raw-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-raw-volume"),
+        "em-fsc-half-mask-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-fsc-half-mask-volume"),
+        "em-fsc-map-model-mask-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-fsc-map-model-mask-volume"),
+        "em-alignment-mask-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-alignment-mask-volume"),
+        "em-focused-refinement-mask-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-focused-refinement-mask-volume"),
+        "em-3d-classification-additional-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-3d-classification-additional-volume"),
+        "em-focus-refinement-additional-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-focus-refinement-additional-volume"),
+        "em-segmentation-volume": (["map", "ccp4", "mrc2000", "bcif"], "em-segmentation-volume"),
         "em-volume-wfcfg": (["json"], "em-volume-wfcfg"),
         "em-mask-volume-wfcfg": (["json"], "em-mask-volume-wfcfg"),
         "em-additional-volume-wfcfg": (["json"], "em-additional-volume-wfcfg"),
@@ -297,6 +305,8 @@ class ConfigInfoData(object):
         "dict-check-report": (["txt"], "dict-check-report"),
         "dict-check-report-r4": (["txt"], "dict-check-report-r4"),
         "dict-check-report-next": (["txt"], "dict-check-report-next"),
+        "tom-complex-report": (["txt"], "tom-upload-report"),
+        "tom-merge-report": (["txt"], "tom-merge-report"),
         "format-check-report": (["txt"], "format-check-report"),
         "misc-check-report": (["txt"], "misc-check-report"),
         "special-position-report": (["txt"], "special-position-report"),
@@ -306,7 +316,7 @@ class ConfigInfoData(object):
         "validation-report": (["pdf"], "val-report"),
         "validation-report-full": (["pdf"], "val-report-full"),
         "validation-report-slider": (["png", "svg"], "val-report-slider"),
-        "validation-data": (["xml"], "val-data"),
+        "validation-data": (["pdbx", "xml"], "val-data"),
         "validation-report-2fo-map-coef": (["pdbx"], "val-report-wwpdb-2fo-fc-edmap-coef"),
         "validation-report-fo-map-coef": (["pdbx"], "val-report-wwpdb-fo-fc-edmap-coef"),
         "validation-report-images": (["tar"], "val-report-images"),
@@ -332,6 +342,10 @@ class ConfigInfoData(object):
         "deposit-volume-params": (["pic"], "deposit-volume-params"),
         "fsc": (["xml"], "fsc-xml"),
         "fsc-report": (["txt"], "fsc-report"),
+        "res-est-fsc": (["xml"], "res-est-fsc"),
+        "res-est-fsc-report": (["txt"], "res-est-fsc-report"),
+        "map-model-fsc": (["xml"], "map-model-fsc"),
+        "map-model-fsc-report": (["txt"], "map-model-fsc-report"),
         "em2em-report": (["txt"], "em2em-report"),
         "img-emdb": (["jpg", "png", "gif", "svg", "tif"], "img-emdb"),
         "img-emdb-report": (["txt"], "img-emdb-report"),
@@ -549,6 +563,12 @@ class ConfigInfoData(object):
     _communication_release_message_subjects.extend(_message_subjects.get("release_with_citation"))
     _communication_release_message_subjects.extend(_message_subjects.get("citation"))
 
+    # mmCIF dictionary
+    _pdbx_dictionary_name_dict = {"ARCHIVE_CURRENT": "mmcif_pdbx_v50", "ARCHIVE_NEXT": "mmcif_pdbx_v50", "DEPOSIT": "mmcif_pdbx_v5_next"}
+
+    # CCD and PRD variables
+    _ref_data_proj_names = {"cvs_path": "/cvs-ligands", "ccd": "ligand-dict-v3", "prd": "prd-v3", "prdcc": "prdcc-v3", "prd_family": "family-v3"}
+
     _projectContentWSiteServiceD = {
         "WWPDB_DEPLOY_PRODUCTION_RU": "https://onedep-contentws-rcsb.wwpdb.org",
         "WWPDB_DEPLOY_LEGACY_RU": "https://onedep-contentws-rcsb.wwpdb.org",
@@ -659,6 +679,12 @@ class ConfigInfoData(object):
         self.__D["PRODUCTION_SITES"] = ConfigInfoData._production_sites
         self.__D["MESSAGE_SUBJECTS"] = ConfigInfoData._message_subjects
         self.__D["COMMUNICATION_RELEASE_MESSAGE_SUBJECTS"] = ConfigInfoData._communication_release_message_subjects
+        self.__D["PDBX_DICTIONARY_NAME_DICT"] = ConfigInfoData._pdbx_dictionary_name_dict
+        self.__D["SITE_REFDATA_CVS_PATH"] = ConfigInfoData._ref_data_proj_names.get("cvs_path")
+        self.__D["SITE_REFDATA_PROJ_NAME_CC"] = ConfigInfoData._ref_data_proj_names.get("ccd")
+        self.__D["SITE_REFDATA_PROJ_NAME_PRD"] = ConfigInfoData._ref_data_proj_names.get("prd")
+        self.__D["SITE_REFDATA_PROJ_NAME_PRDCC"] = ConfigInfoData._ref_data_proj_names.get("prdcc")
+        self.__D["SITE_REFDATA_PROJ_NAME_PRD_FAMILY"] = ConfigInfoData._ref_data_proj_names.get("prd_family")
 
     def getConfigDictionary(self):
         return self.__D
